import javax.persistence.*;

public class Main {

    /* This program works both in Java SE as well as Java EE environment */
    @PersistenceUnit private static EntityManagerFactory emf;

    public static void main(String... args) throws Exception {
        if(emf == null) { // no injection => Java SE
            System.out.println("Defaulting to Java SE enviroment");
            emf = Persistence.createEntityManagerFactory("pu1", null);
        }
        EntityManager em = emf.createEntityManager();
        if(args.length == 0) {
            System.out.println("Usage: java "+ Main.class.getName() + " <name...>");
            System.exit(1);
        }
        for(String id : args) {
            EntityTransaction et = em.getTransaction();
            et.begin();
            System.out.println("*******Finding event " + id);
            EventPK eventPK = new EventPK(id, Event.class.getSimpleName());
            Event event = em.find(Event.class, eventPK);
            if(event == null) {
                event = new Event();
                event.setNotificationId(id);
                System.out.println("Creating event " + event);
                em.persist(event);
            } else {
                System.out.println("Found " + event);
            }
            System.out.println("*******Finding alarm " + id);
            EventPK alarmPK = new EventPK(id, Alarm.class.getSimpleName());
            // cast to work around issue #595
            Alarm alarm = (Alarm)em.find(Event.class, alarmPK);
            if(alarm == null) {
                alarm = new Alarm();
                alarm.setNotificationId(id);
                alarm.setEvent(event);
                System.out.println("Creating alarm " + alarm);
                em.persist(alarm);
            } else {
                System.out.println("Found " + alarm);
            }
            et.commit();
        }
        em.close();
    }
}
